@@ -1,7 +1,7 @@
 package Bencher::Formatter::ModuleStartup;
 
-our $DATE = '2016-06-23'; # DATE
-our $VERSION = '1.011'; # VERSION
+our $DATE = '2016-06-28'; # DATE
+our $VERSION = '1.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,8 +30,8 @@ sub munge_result {
         sub {
             for my $rit (@{$envres->[2]}) {
                 my $rit_baseline = first {
-                    $_->{participant} eq 'perl -e1 (baseline)' &&
-                        $_->{perl} eq $rit->{perl}
+                    ($_->{participant} // '') eq 'perl -e1 (baseline)' &&
+                        ($_->{perl} // '') eq ($rit->{perl} // '')
                     } @{ $envres->[2] };
                 next unless $rit_baseline;
 
@@ -63,7 +63,7 @@ Bencher::Formatter::ModuleStartup - Munge module_startup results
 
 =head1 VERSION
 
-This document describes version 1.011 of Bencher::Formatter::ModuleStartup (from Perl distribution Bencher-Backend), released on 2016-06-23.
+This document describes version 1.012 of Bencher::Formatter::ModuleStartup (from Perl distribution Bencher-Backend), released on 2016-06-28.
 
 =head1 DESCRIPTION
 
